/*	$NetBSD$	*/

/*-
 * Copyright (c) 2009 SHIMIZU Ryo <ryo@nerv.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/cdefs.h>
__KERNEL_RCSID(0, "$NetBSD$");

#include <sys/param.h>
#include <sys/evcnt.h>
#include <sys/systm.h>

#include <machine/intr.h>
#include <machine/lock.h>

#include <arm/star/starreg.h>
#include <arm/star/starvar.h>
#include <arm/star/star_equuleus_intr.h>

void
star_equuleus_set_intrmask(void)
{
	STAR_REG_WRITE32(EQUULEUS_INT_CLEAR, star_intr_enabled);
	STAR_REG_WRITE32(EQUULEUS_INT_MASK, ~star_intr_enabled);
	STAR_REG_WRITE32(EQUULEUS_INT_MASKCLEAR, star_intr_enabled);
}

void
star_equuleus_init()
{
	/* set cpu depend handler */
	star_set_intrmask = star_equuleus_set_intrmask;

	/*
	 * setup Vector Interrupt Control Registers
	 */
	STAR_REG_WRITE32(EQUULEUS_INT_TRIGMODE, 0xffffffff);	/* EdgeTrigger */
	STAR_REG_WRITE32(EQUULEUS_INT_TRIGLEVEL, 0x00000000);	/* HighLevelTrigger */
	STAR_REG_WRITE32(EQUULEUS_INT_FIQSEL, 0x00000000);	/* IRQ mode */
	STAR_REG_WRITE32(EQUULEUS_INT_VIC_EN, 0x00000000);	/* disable VIC */
	STAR_REG_WRITE32(EQUULEUS_INT_SOFTCLEAR, 0xffffffff);	/* clear Software Intr */
	STAR_REG_WRITE32(EQUULEUS_INT_CLEAR, 0xffffffff);	/* clear all interrupt */
	STAR_REG_WRITE32(EQUULEUS_INT_MASK, 0xffffffff);	/* disable all interrupt */
}
